@@ -1,3 +1,4 @@
+from turtle import pos
 import numpy as np
 from pythautomata.base_types.alphabet import Alphabet
 from pythautomata.base_types.sequence import Sequence
@@ -13,9 +14,19 @@ def get_partition(value, partitions):
     limits = np.linspace(0, 1, partitions+1)
     if value == 1:
         return partitions-1
-    for i in range(len(limits)-1):
-        if limits[i] <= value and limits[i+1] > value:
-            return i
+    # for i in range(len(limits)-1):
+    #    if limits[i] <= value and limits[i+1] > value:
+    #        return i
+    positions = list(range(len(limits)-1))
+    mid_element = int(len(limits)/2)
+    while len(positions) > 1:
+        if value >= limits[mid_element]:
+            positions = positions[mid_element:]
+        else:
+            positions = positions[:mid_element]
+        mid_element = positions[int(len(positions)/2)]
+    assert(len(positions) == 1)
+    return positions[0]
 
 
 def get_partitions(observation, partitions):
